<?php  
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */ 

function optionsframework_option_name() {
	// Change this to use your theme slug
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
	return $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'medplus-pro'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
*/

function optionsframework_options() {
	//array of all custom font types.
	$font_types = array( '' => '',
    'ABeeZee' => 'ABeeZee',
    'Abel' => 'Abel',
    'Abril Fatface' => 'Abril Fatface',
    'Aclonica' => 'Aclonica',
    'Acme' => 'Acme',
    'Actor' => 'Actor',
    'Adamina' => 'Adamina',
    'Advent Pro' => 'Advent Pro',
    'Aguafina Script' => 'Aguafina Script',
    'Akronim' => 'Akronim',
    'Aladin' => 'Aladin',
    'Aldrich' => 'Aldrich',
    'Alegreya' => 'Alegreya',
    'Alegreya Sans SC' => 'Alegreya Sans SC',
    'Alegreya SC' => 'Alegreya SC',
    'Alex Brush' => 'Alex Brush',
    'Alef' => 'Alef',
    'Alfa Slab One' => 'Alfa Slab One',
    'Alice' => 'Alice',
    'Alike' => 'Alike',
    'Alike Angular' => 'Alike Angular',
    'Allan' => 'Allan',
    'Allerta' => 'Allerta',
    'Allerta Stencil' => 'Allerta Stencil',
    'Allura' => 'Allura',
    'Almendra' => 'Almendra',
    'Almendra Display' => 'Almendra Display',
    'Almendra SC' => 'Almendra SC',
    'Amiri' => 'Amiri',
    'Amarante' => 'Amarante',
    'Amaranth' => 'Amaranth',
    'Amatic SC' => 'Amatic SC',
    'Amethysta' => 'Amethysta',
    'Amita' => 'Amita',
    'Anaheim' => 'Anaheim',
    'Andada' => 'Andada',
    'Andika' => 'Andika',
    'Annie Use Your Telescope' => 'Annie Use Your Telescope',
    'Anonymous Pro' => 'Anonymous Pro',
    'Antic' => 'Antic',
    'Antic Didone' => 'Antic Didone',
    'Antic Slab' => 'Antic Slab',
    'Anton' => 'Anton',
    'Angkor' => 'Angkor',
    'Arapey' => 'Arapey',
    'Arbutus' => 'Arbutus',
    'Arbutus Slab' => 'Arbutus Slab',
    'Architects Daughter' => 'Architects Daughter',
    'Archivo White' => 'Archivo White',
    'Archivo Narrow' => 'Archivo Narrow',
    'Arial' => 'Arial',
    'Arimo' => 'Arimo',
    'Arya' => 'Arya',
    'Arizonia' => 'Arizonia',
    'Armata' => 'Armata',
    'Artifika' => 'Artifika',
    'Arvo' => 'Arvo',
    'Asar' => 'Asar',
    'Asap' => 'Asap',
    'Asset' => 'Asset',
    'Astloch' => 'Astloch',
    'Asul' => 'Asul',
    'Atomic Age' => 'Atomic Age',
    'Aubrey' => 'Aubrey',
    'Audiowide' => 'Audiowide',
    'Autour One' => 'Autour One',
    'Average' => 'Average',
    'Average Sans' => 'Average Sans',
    'Averia Gruesa Libre' => 'Averia Gruesa Libre',
    'Averia Libre' => 'Averia Libre',
    'Averia Sans Libre' => 'Averia Sans Libre',
    'Averia Serif Libre' => 'Averia Serif Libre',
    'Battambang' => 'Battambang',
    'Bad Script' => 'Bad Script',
    'Bayon' => 'Bayon',
    'Balthazar' => 'Balthazar',
    'Bangers' => 'Bangers',
    'Basic' => 'Basic',
    'Baumans' => 'Baumans',
    'Belgrano' => 'Belgrano',
    'Belleza' => 'Belleza',
    'BenchNine' => 'BenchNine',
    'Bentham' => 'Bentham',
    'Berkshire Swash' => 'Berkshire Swash',
    'Bevan' => 'Bevan',
    'Bigelow Rules' => 'Bigelow Rules',
    'Bigshot One' => 'Bigshot One',
    'Bilbo' => 'Bilbo',
    'Bilbo Swash Caps' => 'Bilbo Swash Caps',
    'Biryani' => 'Biryani',
    'Bitter' => 'Bitter',
    'White Ops One' => 'White Ops One',
    'Bokor' => 'Bokor',
    'Bonbon' => 'Bonbon',
    'Boogaloo' => 'Boogaloo',
    'Bowlby One' => 'Bowlby One',
    'Bowlby One SC' => 'Bowlby One SC',
    'Brawler' => 'Brawler',
    'Bree Serif' => 'Bree Serif',
    'Bubblegum Sans' => 'Bubblegum Sans',
    'Bubbler One' => 'Bubbler One',
    'Buda' => 'Buda',
    'Buenard' => 'Buenard',
    'Butcherman' => 'Butcherman',
    'Butcherman Caps' => 'Butcherman Caps',
    'Butterfly Kids' => 'Butterfly Kids',
    'Cabin' => 'Cabin',
    'Cabin Condensed' => 'Cabin Condensed',
    'Cabin Sketch' => 'Cabin Sketch',
    'Cabin' => 'Cabin',
    'Caesar Dressing' => 'Caesar Dressing',
    'Cagliostro' => 'Cagliostro',
    'Calligraffitti' => 'Calligraffitti',
    'Cambay' => 'Cambay',
    'Cambo' => 'Cambo',
    'Candal' => 'Candal',
    'Cantarell' => 'Cantarell',
    'Cantata One' => 'Cantata One',
    'Cantora One' => 'Cantora One',
    'Capriola' => 'Capriola',
    'Cardo' => 'Cardo',
    'Carme' => 'Carme',
    'Carrois Gothic' => 'Carrois Gothic',
    'Carrois Gothic SC' => 'Carrois Gothic SC',
    'Carter One' => 'Carter One',
    'Caveat' => 'Caveat',
    'Caveat Brush' => 'Caveat Brush',
    'Catamaran' => 'Catamaran',
    'Caudex' => 'Caudex',
    'Cedarville Cursive' => 'Cedarville Cursive',
    'Ceviche One' => 'Ceviche One',
    'Changa One' => 'Changa One',
    'Chango' => 'Chango',
    'Chau Philomene One' => 'Chau Philomene One',
    'Chenla' => 'Chenla',
    'Chela One' => 'Chela One',
    'Chelsea Market' => 'Chelsea Market',
    'Cherry Cream Soda' => 'Cherry Cream Soda',
    'Cherry Swash' => 'Cherry Swash',
    'Chewy' => 'Chewy',
    'Chicle' => 'Chicle',
    'Chivo' => 'Chivo',
    'Chonburi' => 'Chonburi',
    'Cinzel' => 'Cinzel',
    'Cinzel Decorative' => 'Cinzel Decorative',
    'Clicker Script' => 'Clicker Script',
    'Coda' => 'Coda',
    'Codystar' => 'Codystar',
    'Combo' => 'Combo',
    'Comfortaa' => 'Comfortaa',
    'Coming Soon' => 'Coming Soon',
    'Condiment' => 'Condiment',
    'Content' => 'Content',
    'Contrail One' => 'Contrail One',
    'Convergence' => 'Convergence',
    'Cookie' => 'Cookie',
    'Comic Sans MS' => 'Comic Sans MS',
    'Copse' => 'Copse',
    'Corben' => 'Corben',
    'Courgette' => 'Courgette',
    'Cousine' => 'Cousine',
    'Coustard' => 'Coustard',
    'Covered By Your Grace' => 'Covered By Your Grace',
    'Crafty Girls' => 'Crafty Girls',
    'Creepster' => 'Creepster',
    'Creepster Caps' => 'Creepster Caps',
    'Crete Round' => 'Crete Round',
    'Crimson' => 'Crimson',
    'Croissant One' => 'Croissant One',
    'Crushed' => 'Crushed',
    'Cuprum' => 'Cuprum',
    'Cutive' => 'Cutive',
    'Cutive Mono' => 'Cutive Mono',
    'Damion' => 'Damion',
    'Dangrek' => 'Dangrek',
    'Dancing Script' => 'Dancing Script',
    'Dawning of a New Day' => 'Dawning of a New Day',
    'Days One' => 'Days One',
    'Dekko' => 'Dekko',
    'Delius' => 'Delius',
    'Delius Swash Caps' => 'Delius Swash Caps',
    'Delius Unicase' => 'Delius Unicase',
    'Della Respira' => 'Della Respira',
    'Denk One' => 'Denk One',
    'Devonshire' => 'Devonshire',
    'Dhurjati' => 'Dhurjati',
    'Didact Gothic' => 'Didact Gothic',
    'Diplomata' => 'Diplomata',
    'Diplomata SC' => 'Diplomata SC',
    'Domine' => 'Domine',
    'Donegal One' => 'Donegal One',
    'Doppio One' => 'Doppio One',
    'Dorsa' => 'Dorsa',
    'Dosis' => 'Dosis',
    'Dr Sugiyama' => 'Dr Sugiyama',
    'Droid Sans' => 'Droid Sans',
    'Droid Sans Mono' => 'Droid Sans Mono',
    'Droid Serif' => 'Droid Serif',
    'Duru Sans' => 'Duru Sans',
    'Dynalight' => 'Dynalight',
    'EB Garamond' => 'EB Garamond',
    'Eczar' => 'Eczar',
    'Eagle Lake' => 'Eagle Lake',
    'Eater' => 'Eater',
    'Eater Caps' => 'Eater Caps',
    'Economica' => 'Economica',
    'Ek Mukta' => 'Ek Mukta',
    'Electrolize' => 'Electrolize',
    'Elsie' => 'Elsie',
    'Elsie Swash Caps' => 'Elsie Swash Caps',
    'Emblema One' => 'Emblema One',
    'Emilys Candy' => 'Emilys Candy',
    'Engagement' => 'Engagement',
    'Englebert' => 'Englebert',
    'Enriqueta' => 'Enriqueta',
    'Erica One' => 'Erica One',
    'Esteban' => 'Esteban',
    'Euphoria Script' => 'Euphoria Script',
    'Ewert' => 'Ewert',
    'Exo' => 'Exo',
    'Exo 2' => 'Exo 2',
    'Expletus Sans' => 'Expletus Sans',
    'Fanwood Text' => 'Fanwood Text',
    'Fascinate' => 'Fascinate',
    'Fascinate Inline' => 'Fascinate Inline',
    'Fasthand' => 'Fasthand',
    'Faster One' => 'Faster One',
    'Federant' => 'Federant',
    'Federo' => 'Federo',
    'Felipa' => 'Felipa',
    'Fenix' => 'Fenix',
    'Finger Paint' => 'Finger Paint',
    'Fira Mono' => 'Fira Mono',
    'Fira Sans' => 'Fira Sans',
    'Fjalla One' => 'Fjalla One',
    'Fjord One' => 'Fjord One',
    'Flamenco' => 'Flamenco',
    'Flavors' => 'Flavors',
    'Fondamento' => 'Fondamento',
    'Fontdiner Swanky' => 'Fontdiner Swanky',
    'Forum' => 'Forum',
    'Francois One' => 'Francois One',
    'FreeSans' => 'FreeSans',

    'Freckle Face' => 'Freckle Face',
    'Fredericka the Great' => 'Fredericka the Great',
    'Fredoka One' => 'Fredoka One',
    'Fresca' => 'Fresca',
    'Freehand' => 'Freehand',
    'Frijole' => 'Frijole',
    'Fruktur' => 'Fruktur',
    'Fugaz One' => 'Fugaz One',
    'Gafata' => 'Gafata',
    'Galdeano' => 'Galdeano',
    'Galindo' => 'Galindo',
    'Gentium Basic' => 'Gentium Basic',
    'Gentium Book Basic' => 'Gentium Book Basic',
    'Geo' => 'Geo',
    'Georgia' => 'Georgia',
    'Geostar' => 'Geostar',
    'Geostar Fill' => 'Geostar Fill',
    'Germania One' => 'Germania One',
    'Gilda Display' => 'Gilda Display',
    'Give You Glory' => 'Give You Glory',
    'Glass Antiqua' => 'Glass Antiqua',
    'Glegoo' => 'Glegoo',
    'Gloria Hallelujah' => 'Gloria Hallelujah',
    'Goblin One' => 'Goblin One',
    'Gochi Hand' => 'Gochi Hand',
    'Gorditas' => 'Gorditas',
    'Gurajada' => 'Gurajada',
    'Goudy Bookletter 1911' => 'Goudy Bookletter 1911',
    'Graduate' => 'Graduate',
    'Grand Hotel' => 'Grand Hotel',
    'Gravitas One' => 'Gravitas One',
    'Great Vibes' => 'Great Vibes',
    'Griffy' => 'Griffy',
    'Gruppo' => 'Gruppo',
    'Gudea' => 'Gudea',
    'Gidugu' => 'Gidugu',
    'GFS Didot' => 'GFS Didot',
    'GFS Neohellenic' => 'GFS Neohellenic',
    'Habibi' => 'Habibi',
    'Hammersmith One' => 'Hammersmith One',
    'Halant' => 'Halant',
    'Hanalei' => 'Hanalei',
    'Hanalei Fill' => 'Hanalei Fill',
    'Handlee' => 'Handlee',
    'Hanuman' => 'Hanuman',
    'Happy Monkey' => 'Happy Monkey',
    'Headland One' => 'Headland One',
    'Henny Penny' => 'Henny Penny',
    'Herr Von Muellerhoff' => 'Herr Von Muellerhoff',
    'Hind' => 'Hind',
    'Hind Siliguri' => 'Hind Siliguri',
    'Hind Vadodara' => 'Hind Vadodara',
    'Holtwood One SC' => 'Holtwood One SC',
    'Homemade Apple' => 'Homemade Apple',
    'Homenaje' => 'Homenaje',
    'IM Fell' => 'IM Fell',
    'Itim' => 'Itim',
    'Iceberg' => 'Iceberg',
    'Iceland' => 'Iceland',
    'Imprima' => 'Imprima',
    'Inconsolata' => 'Inconsolata',
    'Inder' => 'Inder',
    'Indie Flower' => 'Indie Flower',
    'Inknut Antiqua' => 'Inknut Antiqua',
    'Inika' => 'Inika',
    'Irish Growler' => 'Irish Growler',
    'Istok Web' => 'Istok Web',
    'Italiana' => 'Italiana',
    'Italianno' => 'Italianno',
    'Jacques Francois' => 'Jacques Francois',
    'Jacques Francois Shadow' => 'Jacques Francois Shadow',
    'Jim Nightshade' => 'Jim Nightshade',
    'Jockey One' => 'Jockey One',
    'Jaldi' => 'Jaldi',
    'Jolly Lodger' => 'Jolly Lodger',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Slab' => 'Josefin Slab',
    'Joti One' => 'Joti One',
    'Judson' => 'Judson',
    'Julee' => 'Julee',
    'Julius Sans One' => 'Julius Sans One',
    'Junge' => 'Junge',
    'Jura' => 'Jura',
    'Just Another Hand' => 'Just Another Hand',
    'Just Me Again Down Here' => 'Just Me Again Down Here',
    'Kadwa' => 'Kadwa',
    'Kdam Thmor' => 'Kdam Thmor',
    'Kalam' => 'Kalam', 
    'Kameron' => 'Kameron',
    'Kantumruy' => 'Kantumruy',
    'Karma' => 'Karma',
    'Karla' => 'Karla',
    'Kaushan Script' => 'Kaushan Script',
    'Kavoon' => 'Kavoon',
    'Keania One' => 'Keania One',
    'Kelly Slab' => 'Kelly Slab',
    'Kenia' => 'Kenia',
    'Khand' => 'Khand',
    'Khmer' => 'Khmer',
    'Khula' => 'Khula',
    'Kite One' => 'Kite One',
    'Knewave' => 'Knewave',
    'Kotta One' => 'Kotta One',
    'Kranky' => 'Kranky',
    'Kreon' => 'Kreon',
    'Kristi' => 'Kristi',
    'Koulen' => 'Koulen',
    'Krona One' => 'Krona One',
    'Kurale' => 'Kurale',
    'Lakki Reddy' => 'Lakki Reddy',
    'La Belle Aurore' => 'La Belle Aurore',
    'Lancelot' => 'Lancelot',
    'Laila' => 'Laila',
    'Lato' => 'Lato',
    'Lateef' => 'Lateef',
    'League Script' => 'League Script',
    'Leckerli One' => 'Leckerli One',
    'Ledger' => 'Ledger',
    'Lekton' => 'Lekton',
    'Lemon' => 'Lemon',

    'Libre Baskerville' => 'Libre Baskerville',
    'Life Savers' => 'Life Savers',
    'Lilita One' => 'Lilita One',
    'Limelight' => 'Limelight',
    'Linden Hill' => 'Linden Hill',
    'Lobster' => 'Lobster',
    'Lobster Two' => 'Lobster Two',
    'Londrina Outline' => 'Londrina Outline',
    'Londrina Shadow' => 'Londrina Shadow',
    'Londrina Sketch' => 'Londrina Sketch',
    'Londrina Solid' => 'Londrina Solid',
    'Lora' => 'Lora',
    'Love Ya Like A Sister' => 'Love Ya Like A Sister',
    'Loved by the King' => 'Loved by the King',
    'Lovers Quarrel' => 'Lovers Quarrel',
    'Lucida Sans Unicode' => 'Lucida Sans Unicode',
    'Luckiest Guy' => 'Luckiest Guy',
    'Lusitana' => 'Lusitana',
    'Lustria' => 'Lustria',
    'Macondo' => 'Macondo',
    'Macondo Swash Caps' => 'Macondo Swash Caps',
    'Magra' => 'Magra',
    'Maiden Orange' => 'Maiden Orange',
    'Mallanna' => 'Mallanna',
    'Mandali' => 'Mandali',
    'Mako' => 'Mako',
    'Marcellus' => 'Marcellus',
    'Marcellus SC' => 'Marcellus SC',
    'Marck Script' => 'Marck Script',
    'Margarine' => 'Margarine',
    'Marko One' => 'Marko One',
    'Marmelad' => 'Marmelad',
    'Marvel' => 'Marvel',
    'Martel' => 'Martel',
    'Martel Sans' => 'Martel Sans',
    'Mate' => 'Mate',
    'Mate SC' => 'Mate SC',
    'Maven Pro' => 'Maven Pro',
    'McLaren' => 'McLaren',
    'Meddon' => 'Meddon',
    'MedievalSharp' => 'MedievalSharp',
    'Medula One' => 'Medula One',
    'Megrim' => 'Megrim',
    'Meie Script' => 'Meie Script',
    'Merienda' => 'Merienda',
    'Merienda One' => 'Merienda One',
    'Merriweather' => 'Merriweather',
    'Metal' => 'Metal',
    'Metal Mania' => 'Metal Mania',
    'Metamorphous' => 'Metamorphous',
    'Metrophobic' => 'Metrophobic',
    'Michroma' => 'Michroma',
    'Milonga' => 'Milonga',
    'Miltonian' => 'Miltonian',
    'Miltonian Tattoo' => 'Miltonian Tattoo',
    'Miniver' => 'Miniver',
    'Miss Fajardose' => 'Miss Fajardose',
    'Miss Saint Delafield' => 'Miss Saint Delafield',
    'Modak' => 'Modak',
    'Modern Antiqua' => 'Modern Antiqua',
    'Molengo' => 'Molengo',
    'Molle' => 'Molle',
    'Moulpali' => 'Moulpali',
    'Monda' => 'Monda',
    'Monofett' => 'Monofett',
    'Monoton' => 'Monoton',
    'Monsieur La Doulaise' => 'Monsieur La Doulaise',
    'Montaga' => 'Montaga',
    'Montez' => 'Montez',
    'Montserrat' => 'Montserrat',
    'Montserrat Alternates' => 'Montserrat Alternates',
    'Montserrat Subrayada' => 'Montserrat Subrayada',
    'Mountains of Christmas' => 'Mountains of Christmas',
    'Mouse Memoirs' => 'Mouse Memoirs',
    'Moul' => 'Moul',
    'Mr Bedford' => 'Mr Bedford',
    'Mr Bedfort' => 'Mr Bedfort',
    'Mr Dafoe' => 'Mr Dafoe',
    'Mr De Haviland' => 'Mr De Haviland',
    'Mrs Saint Delafield' => 'Mrs Saint Delafield',
    'Mrs Sheppards' => 'Mrs Sheppards',
    'Muli' => 'Muli',
    'Mystery Quest' => 'Mystery Quest',
    'Neucha' => 'Neucha',
    'Neuton' => 'Neuton',
    'New Rocker' => 'New Rocker',
    'News Cycle' => 'News Cycle',
    'Niconne' => 'Niconne',
    'Nixie One' => 'Nixie One',
    'Nobile' => 'Nobile',
    'Nokora' => 'Nokora',
    'Norican' => 'Norican',
    'Nosifer' => 'Nosifer',
    'Nosifer Caps' => 'Nosifer Caps',
    'Nova Mono' => 'Nova Mono',
    'Noticia Text' => 'Noticia Text',
    'Noto Sans' => 'Noto Sans',
    'Noto Serif' => 'Noto Serif',
    'Nova Round' => 'Nova Round',
    'Numans' => 'Numans',
    'Nunito' => 'Nunito',
    'NTR' => 'NTR',
    'Offside' => 'Offside',
    'Oldenburg' => 'Oldenburg',
    'Oleo Script' => 'Oleo Script',
    'Oleo Script Swash Caps' => 'Oleo Script Swash Caps',
    'Open Sans' => 'Open Sans',
    'Open Sans Condensed' => 'Open Sans Condensed',
    'Oranienbaum' => 'Oranienbaum',
    'Orbitron' => 'Orbitron',
    'Odor Mean Chey' => 'Odor Mean Chey',
    'Oregano' => 'Oregano',
    'Orienta' => 'Orienta',
    'Original Surfer' => 'Original Surfer',
    'Oswald' => 'Oswald',
    'Over the Rainbow' => 'Over the Rainbow',
    'Overlock' => 'Overlock',
    'Overlock SC' => 'Overlock SC',
    'Ovo' => 'Ovo',
    'Oxygen' => 'Oxygen',
    'Oxygen Mono' => 'Oxygen Mono',
    'Palanquin Dark' => 'Palanquin Dark',
    'Peddana' => 'Peddana',
    'Poppins' => 'Poppins',
    'PT Mono' => 'PT Mono',
    'PT Sans' => 'PT Sans',
    'PT Sans Caption' => 'PT Sans Caption',
    'PT Sans Narrow' => 'PT Sans Narrow',
    'PT Serif' => 'PT Serif',
    'PT Serif Caption' => 'PT Serif Caption',
    'Pacifico' => 'Pacifico',
    'Paprika' => 'Paprika',
    'Parisienne' => 'Parisienne',
    'Passero One' => 'Passero One',
    'Passion One' => 'Passion One',
    'Patrick Hand' => 'Patrick Hand',
    'Patrick Hand SC' => 'Patrick Hand SC',
    'Patua One' => 'Patua One',
    'Paytone One' => 'Paytone One',
    'Peralta' => 'Peralta',
    'Permanent Marker' => 'Permanent Marker',
    'Petit Formal Script' => 'Petit Formal Script',
    'Petrona' => 'Petrona',
    'Philosopher' => 'Philosopher',
    'Piedra' => 'Piedra',
    'Pinyon Script' => 'Pinyon Script',
    'Pirata One' => 'Pirata One',
    'Plaster' => 'Plaster',
    'Palatino Linotype' => 'Palatino Linotype',
    'Play' => 'Play',
    'Playball' => 'Playball',
    'Playfair Display' => 'Playfair Display',
    'Playfair Display SC' => 'Playfair Display SC',
    'Podkova' => 'Podkova',
    'Poiret One' => 'Poiret One',
    'Poller One' => 'Poller One',
    'Poly' => 'Poly',
    'Pompiere' => 'Pompiere',
    'Pontano Sans' => 'Pontano Sans',
    'Port Lligat Sans' => 'Port Lligat Sans',
    'Port Lligat Slab' => 'Port Lligat Slab',
    'Prata' => 'Prata',
    'Pragati Narrow' => 'Pragati Narrow',
    'Preahvihear' => 'Preahvihear',
    'Press Start 2P' => 'Press Start 2P',
    'Princess Sofia' => 'Princess Sofia',
    'Prociono' => 'Prociono',
    'Prosto One' => 'Prosto One',
    'Puritan' => 'Puritan',
    'Purple Purse' => 'Purple Purse',
    'Quando' => 'Quando',
    'Quantico' => 'Quantico',
    'Quattrocento' => 'Quattrocento',
    'Quattrocento Sans' => 'Quattrocento Sans',
    'Questrial' => 'Questrial',
    'Quicksand' => 'Quicksand',
    'Quintessential' => 'Quintessential',
    'Qwigley' => 'Qwigley',
    'Racing Sans One' => 'Racing Sans One',
    'Radley' => 'Radley',
    'Rajdhani' => 'Rajdhani',
    'Raleway Dots' => 'Raleway Dots',
    'Raleway' => 'Raleway',
    'Rambla' => 'Rambla',
    'Ramabhadra' => 'Ramabhadra',
    'Ramaraja' => 'Ramaraja',
    'Rammetto One' => 'Rammetto One',
    'Ranchers' => 'Ranchers',
    'Rancho' => 'Rancho',
    'Ranga' => 'Ranga',
    'Ravi Prakash' => 'Ravi Prakash',
    'Rationale' => 'Rationale',
    'Redressed' => 'Redressed',
    'Reenie Beanie' => 'Reenie Beanie',
    'Revalia' => 'Revalia',
    'Rhodium Libre' => 'Rhodium Libre',
    'Ribeye' => 'Ribeye',
    'Ribeye Marrow' => 'Ribeye Marrow',
    'Righteous' => 'Righteous',
    'Risque' => 'Risque',
    'Roboto' => 'Roboto',
    'Roboto Condensed' => 'Roboto Condensed',
    'Roboto Mono' => 'Roboto Mono',
    'Roboto Slab' => 'Roboto Slab',
    'Rochester' => 'Rochester',
    'Rock Salt' => 'Rock Salt',
    'Rokkitt' => 'Rokkitt',
    'Romanesco' => 'Romanesco',
    'Ropa Sans' => 'Ropa Sans',
    'Rosario' => 'Rosario',
    'Rosarivo' => 'Rosarivo',
    'Rouge Script' => 'Rouge Script',
    'Rozha One' => 'Rozha One',
    'Rubik' => 'Rubik',
    'Rubik One' => 'Rubik One',
    'Rubik Mono One' => 'Rubik Mono One',
    'Ruda' => 'Ruda',
    'Rufina' => 'Rufina',
    'Ruge Boogie' => 'Ruge Boogie',
    'Ruluko' => 'Ruluko',
    'Rum Raisin' => 'Rum Raisin',
    'Ruslan Display' => 'Ruslan Display',
    'Russo One' => 'Russo One',
    'Ruthie' => 'Ruthie',
    'Rye' => 'Rye',
    'Sacramento' => 'Sacramento',
    'Sail' => 'Sail',
    'Salsa' => 'Salsa',
    'Sanchez' => 'Sanchez',
    'Sancreek' => 'Sancreek',
    'Sahitya' => 'Sahitya',
    'Sansita One' => 'Sansita One',
    'Sarpanch' => 'Sarpanch',
    'Sarina' => 'Sarina',
    'Satisfy' => 'Satisfy',
    'Scada' => 'Scada',
    'Scheherazade' => 'Scheherazade',
    'Schoolbell' => 'Schoolbell',
    'Seaweed Script' => 'Seaweed Script',
    'Sarala' => 'Sarala',
    'Sevillana' => 'Sevillana',
    'Seymour One' => 'Seymour One',
    'Shadows Into Light' => 'Shadows Into Light',
    'Shadows Into Light Two' => 'Shadows Into Light Two',
    'Shanti' => 'Shanti',
    'Share' => 'Share',
    'Share Tech' => 'Share Tech',
    'Share Tech Mono' => 'Share Tech Mono',
    'Shojumaru' => 'Shojumaru',
    'Short Stack' => 'Short Stack',
    'Sigmar One' => 'Sigmar One',
    'Suranna' => 'Suranna',
    'Suravaram' => 'Suravaram',
    'Suwannaphum' => 'Suwannaphum',
    'Signika' => 'Signika',
    'Signika Negative' => 'Signika Negative',
    'Simonetta' => 'Simonetta',
    'Siemreap' => 'Siemreap',
    'Sirin Stencil' => 'Sirin Stencil',
    'Six Caps' => 'Six Caps',
    'Skranji' => 'Skranji',
    'Slackey' => 'Slackey',
    'Smokum' => 'Smokum',
    'Smythe' => 'Smythe',
    'Sniglet' => 'Sniglet',
    'Snippet' => 'Snippet',
    'Snowburst One' => 'Snowburst One',
    'Sofadi One' => 'Sofadi One',
    'Sofia' => 'Sofia',
    'Sonsie One' => 'Sonsie One',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Source Code Pro' => 'Source Code Pro',
    'Source Sans Pro' => 'Source Sans Pro',
    'Special I am one' => 'Special I am one',
    'Spicy Rice' => 'Spicy Rice',
    'Spinnaker' => 'Spinnaker',
    'Spirax' => 'Spirax',
    'Squada One' => 'Squada One',
    'Sree Krushnadevaraya' => 'Sree Krushnadevaraya',
    'Stalemate' => 'Stalemate',
    'Stalinist One' => 'Stalinist One',
    'Stardos Stencil' => 'Stardos Stencil',
    'Stint Ultra Condensed' => 'Stint Ultra Condensed',
    'Stint Ultra Expanded' => 'Stint Ultra Expanded',
    'Stoke' => 'Stoke',
    'Stoke' => 'Stoke',
    'Strait' => 'Strait',
    'Sura' => 'Sura',
    'Sumana' => 'Sumana',
    'Sue Ellen Francisco' => 'Sue Ellen Francisco',
    'Sunshiney' => 'Sunshiney',
    'Supermercado One' => 'Supermercado One',
    'Swanky and Moo Moo' => 'Swanky and Moo Moo',
    'Syncopate' => 'Syncopate',
    'Symbol' => 'Symbol',
    'Timmana' => 'Timmana',
    'Taprom' => 'Taprom',
    'Tangerine' => 'Tangerine',
    'Tahoma' => 'Tahoma',
    'Teko' => 'Teko',
    'Telex' => 'Telex',
    'Tenali Ramakrishna' => 'Tenali Ramakrishna',
    'Tenor Sans' => 'Tenor Sans',
    'Terminal Dosis' => 'Terminal Dosis',
    'Terminal Dosis Light' => 'Terminal Dosis Light',
    'Text Me One' => 'Text Me One',
    'The Girl Next Door' => 'The Girl Next Door',
    'Tienne' => 'Tienne',
    'Tillana' => 'Tillana',
    'Tinos' => 'Tinos',
    'Titan One' => 'Titan One',
    'Titillium Web' => 'Titillium Web',
    'Trade Winds' => 'Trade Winds',
    'Trebuchet MS' => 'Trebuchet MS',
    'Trocchi' => 'Trocchi',
    'Trochut' => 'Trochut',
    'Trykker' => 'Trykker',
    'Tulpen One' => 'Tulpen One',
    'Ubuntu' => 'Ubuntu',
    'Ubuntu Condensed' => 'Ubuntu Condensed',
    'Ubuntu Mono' => 'Ubuntu Mono',
    'Ultra' => 'Ultra',
    'Uncial Antiqua' => 'Uncial Antiqua',
    'Underdog' => 'Underdog',
    'Unica One' => 'Unica One',
    'UnifrakturCook' => 'UnifrakturCook',
    'UnifrakturMaguntia' => 'UnifrakturMaguntia',
    'Unkempt' => 'Unkempt',
    'Unlock' => 'Unlock',
    'Unna' => 'Unna',
    'VT323' => 'VT323',
    'Vampiro One' => 'Vampiro One',
    'Varela' => 'Varela',
    'Varela Round' => 'Varela Round',
    'Vast Shadow' => 'Vast Shadow',
    'Vesper Libre' => 'Vesper Libre',
    'Verdana' => 'Verdana',
    'Vibur' => 'Vibur',
    'Vidaloka' => 'Vidaloka',
    'Viga' => 'Viga',
    'Voces' => 'Voces',
    'Volkhov' => 'Volkhov',
    'Vollkorn' => 'Vollkorn',
    'Voltaire' => 'Voltaire',
    'Waiting for the Sunrise' => 'Waiting for the Sunrise',
    'Wallpoet' => 'Wallpoet',
    'Walter Turncoat' => 'Walter Turncoat',
    'Warnes' => 'Warnes',
    'Wellfleet' => 'Wellfleet',
    'Wendy One' => 'Wendy One',
    'Wire One' => 'Wire One',
    'Yanone Kaffeesatz' => 'Yanone Kaffeesatz',
    'Yantramanav' => 'Yantramanav',
    'Yellowtail' => 'Yellowtail',
    'Yeseva One' => 'Yeseva One',
    'Yesteryear' => 'Yesteryear',
    'Zeyada' => 'Zeyada'
  );

	//array of all font sizes.
	$font_sizes = array( 
		'10px' => '10px',
		'11px' => '11px',
	);
	
	$options = array();
	$imagepath =  get_template_directory_uri() . '/images/';

	
	for($n=12;$n<=200;$n+=1){
		$font_sizes[$n.'px'] = $n.'px';
	}
	
	// Pull all the pages into an array
	 $options_pages = array();
	 $options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	 $options_pages[''] = 'Select a page:';
	 foreach ($options_pages_obj as $page) {
	  $options_pages[$page->ID] = $page->post_title;
	 }

	// array of section content.
	$section_text = array(	
		 1 => array(
			'section_title'	=> '',
			'menutitle'		=> 'buynowtheme',
			'bgcolor' 		=> '',
			'bgimage'		=> get_template_directory_uri().'/images/buynowbg.jpg',
			'class'			=> 'buynowwrap',
			'content'		=> '<h2>Medplus Theme is Suitable for any type of Medical and Multipurpose Business Projects.</h2>[button align="center" name="Buy This Theme" link="https://gracethemes.com/themes/medplus-wordpress-medical-theme/" target=""]'
		 ),
		 
		 2 => array(
			'section_title'	=> '',
			'menutitle'		=> 'aboutustheme',
			'bgcolor' 		=> '',
			'bgimage'		=> '',
			'class'			=> 'abtthemewrap',
			'content'		=> '[column_content type="one_half"]<img src="'.get_template_directory_uri().'/images/doctoricon.png" alt="" />[/column_content]

[column_content type="one_half_last"]<h2>Welcome to Our Medplus Theme</h2><p> Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus consectetuer adipiscing elit.</p>

<p>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium.Integer tincidunt Cras dapibus. Vivamus elementum semper nisi.Aenean vulputate eleifend tellus consectetuer adipiscing Cras dapibus. Vivamus elementum semper nisi.</p>
<p> Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus consectetuer adipiscing Vivamus elementum semper nisi.Aenean Aenean commodo ligula eget dolor vulputate eleifend tellus  elit.</p>[/column_content]'
		 ),
		
		 3 => array(
			'section_title'	=> 'Our Medical Specialists',
			'menutitle'		=> 'teamsection',
			'bgcolor' 		=> '#f5f4f4',
			'bgimage'		=> '',
			'class'			=> 'teamareawrap',
			'content'		=> '[our-doctor show="4"] ',
		),	
		
		4 => array(
			'section_title'	=> 'Medplus Theme Features',
			'menutitle'		=> 'themefeatures',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'featureswrap',
			'content'		=> '[column_content type="one_fourth"]<i class="fa fa-gear"></i>
			<h3>Free Installation</h3>
<p>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis.</p>
	<a class="button" href="#">Read More</a>
[/column_content]

[column_content type="one_fourth"]<i class="fa fa-envelope"></i>
<h3>Quick & Friendly Support</h3>
<p>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis.</p>
	<a class="button" href="#">Read More</a>
[/column_content]

[column_content type="one_fourth"]<i class="fa fa-diamond"></i>
<h3>Translation Ready</h3>
<p>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis.</p>
	<a class="button" href="#">Read More</a>
[/column_content]

[column_content type="one_fourth_last"]<i class="fa fa-mobile"></i>
<h3>Responsive Ready</h3>
<p>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum.</p>
	<a class="button" href="#">Read More</a>
[/column_content]'
		),		
		
		5 => array(
			'section_title'	=> 'Our Skills',
			'menutitle'		=> 'ourskills',
			'bgcolor' 		=> '#f5f4f4',
			'bgimage'		=> '',
			'class'			=> 'skillswrap',
			'content'		=> '[counter iconname="fa-user-md" value="35" title="Our Staff"][counter iconname="fa-wheelchair" value="15" title="Our Department"][counter iconname="fa-list" value="2560" title="Our Patient List"] [counter iconname="fa-graduation-cap" value="560" title="Our Awards"]'
		),
		
		
		6 => array(
			'section_title'	=> 'Latest News',
			'menutitle'		=> 'newswraper',
			'bgcolor' 		=> '',
			'bgimage'		=> '',
			'class'			=> 'newsareawrap',
			'content'		=> '[latest-news showposts="4" comment="show" date="show" author="show"]',
		),	

		
		7 => array(
			'section_title'	=> 'Clients Testimonials',
			'menutitle'		=> 'testimonialswrap',
			'bgcolor' 		=> '',
			'bgimage'		=> get_template_directory_uri().'/images/testimonialsbg.jpg',
			'class'			=> 'tmareawrap',
			'content'		=> '[testimonials]'
		),		
		
		8 => array(
			'section_title'	=> 'Our Departments',
			'menutitle'		=> 'departmentarea',
			'bgcolor' 		=> '#f5f4f4',
			'bgimage'		=> '',
			'class'			=> 'dpareawrap',
			'content'		=> '<p>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo Nullam dictum felis.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum massa quis enim.Donec pede justo felis.</p>[departments_lists][department image="'.get_template_directory_uri().'/images/dp-icon2.png" title="Neurology" link="#"][department image="'.get_template_directory_uri().'/images/dp-icon4.png" title="Dental Care" link="#"][department image="'.get_template_directory_uri().'/images/dp-icon1.png" title="Cardiology" link="#"][department image="'.get_template_directory_uri().'/images/dp-icon3.png" title="Eye Care" link="#"][department image="'.get_template_directory_uri().'/images/dp-icon5.png" title="Orthopedic" link="#"][/departments_lists]',
		),	
		
		9 => array(
			'section_title'	=> 'Our Gallery',
			'menutitle'		=> 'home-gallery',
			'bgcolor' 		=> '',
			'bgimage'		=> '',
			'class'			=> 'gallerywrap',
			'content'		=> '[photogallery filter="false"] [button align="center" name="View Gallery" link="#"]',
		),	
		
		10 => array(
			'section_title'	=> 'Our Partners',
			'menutitle'		=> 'ourclients',
			'bgcolor' 		=> '#f5f4f4',
			'bgimage'		=> '',
			'bgvideo'		=> '',
			'class'			=> 'clientwrap',
			'content'		=> '[client_lists][client image="'.get_template_directory_uri().'/images/client-logo1.jpg" link="#"][client image="'.get_template_directory_uri().'/images/client-logo2.jpg" link="#"][client image="'.get_template_directory_uri().'/images/client-logo3.jpg" link="#"][client image="'.get_template_directory_uri().'/images/client-logo4.jpg" link="#"][client image="'.get_template_directory_uri().'/images/client-logo5.jpg" link="#"][/client_lists]',
		),

	);

	$options = array();

	//Basic Settings
	$options[] = array(
		'name' => __('Basic Settings', 'medplus-pro'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Logo', 'medplus-pro'),
		'desc' => __('Upload your site logo from here', 'medplus-pro'),
		'id' => 'logo',
		'class' => '',
		'std'	=> get_template_directory_uri()."/images/logo.png",
		'type' => 'upload');
		
	$options[] = array(		
		'desc' => __('logo height', 'medplus-pro'),
		'id' => 'logoheight',
		'std' => '55',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Sticky Header', 'medplus-pro'),
		'desc' => __('Check this to disable sticky header on scroll', 'medplus-pro'),
		'id' => 'headstick',
		'std' => '',
		'type' => 'checkbox');	
		
	$options[] = array(
		'name' => __('Disable Animation', 'medplus-pro'),
		'desc' => __('Check this to disable animation on scroll', 'medplus-pro'),
		'id' => 'scrollanimation',
		'std' => '',
		'type' => 'checkbox');			

	$options[] = array(
		'name' => __('Custom CSS', 'medplus-pro'),
		'desc' => __('Some Custom Styling for your site. Place any css codes here instead of the style.css file.', 'medplus-pro'),
		'id' => 'style2',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Header Top Info', 'medplus-pro'),
		'desc' => __('Edit header info from here. NOTE: Icon name should be in lowercase without space.(exa.phone) More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/', 'medplus-pro'),
		'id' => 'headerinfo',
		'std' => '<i class="fa fa-phone"></i> <span class="phno">+11 123 456 7890</span> <i class="fa fa-envelope"></i>demomail@gmail.com ',
		'type' => 'textarea');	
		
	$options[] = array(
		'name' => __('Header Top Social Icons', 'medplus-pro'),
		'desc' => __('Edit select social icons for header top', 'medplus-pro'),
		'id' => 'headersocial',
		'std' => ' [social_area]<span>Follow us:</span> [social icon="facebook" link="#"] [social icon="twitter" link="#"] [social icon="google-plus" link="#"] [social icon="linkedin" link="#"][/social_area]',
		'type' => 'textarea');	
		
		
	// font family start 
		
	$options[] = array(
		'name' => __('Font Faces', 'medplus-pro'),
		'desc' => __('Select font for the body text', 'medplus-pro'),
		'id' => 'bodyfontface',
		'type' => 'select',
		'std' => 'Open Sans',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the textual logo', 'medplus-pro'),
		'id' => 'logofontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the navigation text', 'medplus-pro'),
		'id' => 'navfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for heading text. eg: Section Title', 'medplus-pro'),
		'id' => 'headfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
			
	$options[] = array(
		'desc' => __('Select font for Slide title', 'medplus-pro'),
		'id' => 'slidetitlefontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );	
		
	$options[] = array(
		'desc' => __('Select font for Slide Description', 'medplus-pro'),
		'id' => 'slidedesfontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );	

		
	// font sizes start	
	$options[] = array(
		'name' => __('Font Sizes', 'medplus-pro'),
		'desc' => __('Select font size for body text', 'medplus-pro'),
		'id' => 'bodyfontsize',
		'type' => 'select',
		'std' => '13px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for textual logo', 'medplus-pro'),
		'id' => 'logofontsize',
		'type' => 'select',
		'std' => '40px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for navigation', 'medplus-pro'),
		'id' => 'navfontsize',
		'type' => 'select',
		'std' => '14px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for section title', 'medplus-pro'),
		'id' => 'sectitlesize',
		'type' => 'select',
		'std' => '34px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for our services and our team', 'medplus-pro'),
		'id' => 'teamservfontsize',
		'type' => 'select',
		'std' => '16px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for footer title', 'medplus-pro'),
		'id' => 'ftfontsize',
		'type' => 'select',
		'std' => '20px',
		'options' => $font_sizes );	

	$options[] = array(
		'desc' => __('Select h1 font size', 'medplus-pro'),
		'id' => 'h1fontsize',
		'std' => '32px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h2 font size', 'medplus-pro'),
		'id' => 'h2fontsize',
		'std' => '28px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h3 font size', 'medplus-pro'),
		'id' => 'h3fontsize',
		'std' => '18px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h4 font size', 'medplus-pro'),
		'id' => 'h4fontsize',
		'std' => '22px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h5 font size', 'medplus-pro'),
		'id' => 'h5fontsize',
		'std' => '20px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h6 font size', 'medplus-pro'),
		'id' => 'h6fontsize',
		'std' => '14px',
		'type' => 'select',
		'options' => $font_sizes);


	// font colors start

	$options[] = array(
		'name' => __('Font Colors', 'medplus-pro'),
		'desc' => __('Select font color for the body text', 'medplus-pro'),
		'id' => 'bodyfontcolor',
		'std' => '#555555',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for textual logo', 'medplus-pro'),
		'id' => 'logofontcolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for logo tagline', 'medplus-pro'),
		'id' => 'logotaglinecolor',
		'std' => '#828181',
		'type' => 'color');
		
	

	$options[] = array(
		'desc' => __('Select font color for social icons', 'medplus-pro'),
		'id' => 'socialfontcolor',
		'std' => '#a5a5a5',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font hover color for social icons', 'medplus-pro'),
		'id' => 'socialfonthvcolor',
		'std' => '#e14165',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for section title', 'medplus-pro'),
		'id' => 'sectitlecolor',
		'std' => '#515151',
		'type' => 'color');	
		
	
	$options[] = array(
		'desc' => __('Select font color for navigation', 'medplus-pro'),
		'id' => 'navfontcolor',
		'std' => '#515151',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for navigation hover', 'medplus-pro'),
		'id' => 'navhovercolor',
		'std' => '#e14165',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for widget title', 'medplus-pro'),
		'id' => 'wdgttitleccolor',
		'std' => '#515151',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer title', 'medplus-pro'),
		'id' => 'foottitlecolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer', 'medplus-pro'),
		'id' => 'footdesccolor',
		'std' => '#595959',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer menu ', 'medplus-pro'),
		'id' => 'footermenucolor',
		'std' => '#E14165',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font hover color for footer menu ', 'medplus-pro'),
		'id' => 'footermenucurrent',
		'std' => '#8e8d8d',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for footer left text (copyright)', 'medplus-pro'),
		'id' => 'copycolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer right text (design by)', 'medplus-pro'),
		'id' => 'designcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for links / anchor tags', 'medplus-pro'),
		'id' => 'linkcolor',
		'std' => '#E14165',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font hover color for links / anchor tags', 'medplus-pro'),
		'id' => 'linkhovercolor',
		'std' => '#272727',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for sidebar li a', 'medplus-pro'),
		'id' => 'sidebarfontcolor',
		'std' => '#78797c',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for sidebar li a', 'medplus-pro'),
		'id' => 'sidebarfonthvcolor',
		'std' => '#E14165',
		'type' => 'color');			
			
	
	$options[] = array(
		'desc' => __('Select font color for footer links', 'medplus-pro'),
		'id' => 'copylinks',
		'std' => '#E14165',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer links', 'medplus-pro'),
		'id' => 'copylinkshover',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h1 font color', 'medplus-pro'),
		'id' => 'h1fontcolor',
		'std' => '#515151',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select h2 font color', 'medplus-pro'),
		'id' => 'h2fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select h3 font color', 'medplus-pro'),
		'id' => 'h3fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select h4 font color', 'medplus-pro'),
		'id' => 'h4fontcolor',
		'std' => '#515151',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h5 font color', 'medplus-pro'),
		'id' => 'h5fontcolor',
		'std' => '#515151',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h6 font color', 'medplus-pro'),
		'id' => 'h6fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for header top section', 'medplus-pro'),
		'id' => 'headertopcolor',
		'std' => '#A5A5A5',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for get an appointment section', 'medplus-pro'),
		'id' => 'appoint-sec-fontcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for get an appointment section title', 'medplus-pro'),
		'id' => 'appoint-sec-title',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for last word colorful for title', 'medplus-pro'),
		'id' => 'lastwordcolor',
		'std' => '#E14165',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for counter circle box', 'medplus-pro'),
		'id' => 'countercirclecolor',
		'std' => '#111111',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for counter circle number', 'medplus-pro'),
		'id' => 'countercirclenumber',
		'std' => '#E14165',
		'type' => 'color');	

		
	$options[] = array(
		'desc' => __('Select font color for testimonials title', 'medplus-pro'),
		'id' => 'testimonialtitle',
		'std' => '#ffffff',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font color for testimonials decription', 'medplus-pro'),
		'id' => 'testimonialdesc',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer social icons', 'medplus-pro'),
		'id' => 'footsocialcolor',
		'std' => '#303030',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer social icons', 'medplus-pro'),
		'id' => 'footsocialhvcolor',
		'std' => '#E14165',
		'type' => 'color');				
		
		
			
									

	// Background start		
	$options[] = array(	
		'name' => __('Background Colors', 'medplus-pro'),	
		'desc' => __('Select background color for header', 'medplus-pro'),
		'id' => 'headerbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
	
	$options[] = array(
		'desc' => __('Select background color for header nav dropdown', 'medplus-pro'),
		'id' => 'navdpbgcolor',
		'std' => '#ffffff',
		'type' => 'color');
	

	$options[] = array(
		'desc' => __('Select background color for footer', 'medplus-pro'),
		'id' => 'footerbgcolor',
		'std' => '#242323',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for copyright section', 'medplus-pro'),
		'id' => 'copybgcolor',
		'std' => '#1a191a',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select background color for toggle menu', 'medplus-pro'),
		'id' => 'togglemenu',
		'std' => '#E14165',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for header top', 'medplus-pro'),
		'id' => 'headertopbgcolor',
		'std' => '#F7F7F7',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for get an appointment section', 'medplus-pro'),
		'id' => 'appoint-sec-bgcolor',
		'std' => '#E14165',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for our medical specialists box', 'medplus-pro'),
		'id' => 'teambgcolor',
		'std' => '#ffffff',
		'type' => 'color');		

	// Border colors
	$options[] = array(
		'name' => __('Border Colors', 'medplus-pro'),	
		'desc' => __('Select border color for All', 'medplus-pro'),
		'id' => 'allbdcolor',
		'std' => '#E14165',
		'type' => 'color');
			
	$options[] = array(	
		'desc' => __('Select border color for footer posts', 'medplus-pro'),
		'id' => 'footerpostborder',
		'std' => '#5e6162',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar li a', 'medplus-pro'),
		'id' => 'sidebarliaborder',
		'std' => '#d0cfcf',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for header top', 'medplus-pro'),
		'id' => 'headertopborder',
		'std' => '#EAEAEA',
		'type' => 'color');
		
	$options[] = array(			
		'desc' => __('Select border color for get an appointment section', 'medplus-pro'),
		'id' => 'appoint-sec-border',
		'std' => '#CD2B4F',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for our doctor degignation', 'medplus-pro'),
		'id' => 'teamborder',
		'std' => '#EAEAEA',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar widget title', 'medplus-pro'),
		'id' => 'widgettitleborder',
		'std' => '#E8E8E8',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar widget box', 'medplus-pro'),
		'id' => 'widgetboxborder',
		'std' => '#E8E8E8',
		'type' => 'color');				
		
		

	// Default Buttons		
	$options[] = array(
		'name' => __('Button Colors', 'medplus-pro'),		
		'desc' => __('Select background color for default button', 'medplus-pro'),
		'id' => 'btnbgcolor',
		'std' => '#E14165',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background hover color for default button', 'medplus-pro'),
		'id' => 'btnbghvcolor',
		'std' => '#424242',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select font color default button', 'medplus-pro'),
		'id' => 'btntxtcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font hover color for default button', 'medplus-pro'),
		'id' => 'btntxthvcolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for get an appointment button', 'medplus-pro'),
		'id' => 'appontmentbtn',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for get an appointment button', 'medplus-pro'),
		'id' => 'appontmentbtnhover',
		'std' => '#515151',
		'type' => 'color');
		

	// Slider Caption colors	
	$options[] = array(	
		'name' => __('Slider Caption Colors', 'medplus-pro'),			
		'desc' => __('Select font color for slider title', 'medplus-pro'),
		'id' => 'slidetitlecolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for slider description', 'medplus-pro'),
		'id' => 'slidedesccolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font size for slider title', 'medplus-pro'),
		'id' => 'slidetitlefontsize',
		'type' => 'select',
		'std' => '50px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for slider title span', 'medplus-pro'),
		'id' => 'slidetitlespan',
		'type' => 'select',
		'std' => '30px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for slider description', 'medplus-pro'),
		'id' => 'slidedescfontsize',
		'type' => 'select',
		'std' => '14px',
		'options' => $font_sizes );
		
	// Slider controls colors		
	$options[] = array(
		'name' => __('Slider controls Colors', 'medplus-pro'),
		'desc' => __('Select background color for slider pager', 'medplus-pro'),
		'id' => 'sldpagebg',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background active color for slider pager', 'medplus-pro'),
		'id' => 'sldpagehvbg',
		'std' => '#E14165',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select Border color for slider pager', 'medplus-pro'),
		'id' => 'sldpagehvbd',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'name' => __('Blog Single Layout', 'medplus-pro'),
		'desc' => __('Select layout. eg:Boxed, Wide', 'medplus-pro'),
		'id' => 'singlelayout',
		'type' => 'select',
		'std' => 'singleright',
		'options' => array('singleright'=>'Blog Single Right Sidebar', 'singleleft'=>'Blog Single Left Sidebar', 'sitefull'=>'Blog Single Full Width', 'nosidebar'=>'Blog Single No Sidebar') );
		
	$options[] = array(
		'name' => __('Woocommerce Page Layout', 'medplus-pro'),
		'desc' => __('Select layout. eg:right-sidebar, left-sidebar, full-width', 'medplus-pro'),
		'id' => 'woocommercelayout',
		'type' => 'select',
		'std' => 'woocommercesitefull',
		'options' => array('woocommerceright'=>'Woocommerce Right Sidebar', 'woocommerceleft'=>'Woocommerce Left Sidebar', 'woocommercesitefull'=>'Woocommerce Full Width') );		
	
		
	$options[] = array(
		'name' => __('Excerpt Length', 'medplus-pro'),	
		'desc' => __('manage excerpt length for Our Medical Specialists section', 'medplus-pro'),
		'id' => 'teamexcerptlength',
		'std' => '20',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('manage excerpt length for latest news section', 'medplus-pro'),
		'id' => 'latestnewslength',
		'std' => '15',
		'type' => 'text');
		
	$options[] = array(	
		'name' => __('Testimonials Rotating Speed', 'medplus-pro'),	
		'desc' => __('manage testimonials rotating speed.', 'medplus-pro'),
		'id' => 'testimonialsrotatingspeed',
		'std' => '8000',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('True/False Auto play Testimonials.','medplus-pro'),
		'id' => 'testimonialsautoplay',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'True', 'false'=>'False'));	
		
	$options[] = array(		
		'desc' => __('manage excerpt length for testimonials', 'medplus-pro'),
		'id' => 'testimonialsexcerptlength',
		'std' => '45',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Read More Button Text', 'medplus-pro'),	
		'desc' => __('change read more button text for latest news section', 'medplus-pro'),
		'id' => 'latestnewsreadmoretext',
		'std' => 'Read More &raquo;',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Responsive View Menu word Changeable', 'medplus-pro'),
		'desc' => __('Change menu word on responsive view', 'medplus-pro'),
		'id' => 'menuwordchange',
		'std' => 'Menu',
		'type' => 'text');				
		

	//Layout Settings
	$options[] = array(
		'name' => __('Sections', 'medplus-pro'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Get an Appointment Page','medplus-pro'),
		'desc'	=> __('Select the Get an appointment Today page for frontpage section','medplus-pro'),
		'id' 	=> 'appointment',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('Select excerpt length for get an appointment section', 'medplus-pro'),
		'id' => 'appointexcerptlength',
		'std' => '20',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('manage get an appointment button text', 'medplus-pro'),
		'id' => 'appointbutton',
		'std' => 'Get an Appointment',
		'type' => 'text');		
	
	$options[] = array(			
			'desc'	=> __('Check to hide Get an Appointment section below the slider', 'business-growth'),
			'id'	=> 'hideappointmentsec',
			'type'	=> 'checkbox',
			'std'	=> '');	
		
	$options[] = array(
		'name' => __('Welcome and Our Services Section','medplus-pro'),
		'desc'	=> __('Popular Top 29 Medical text WordPress Theme','medplus-pro'),
		'id' 	=> 'welcomepage',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('Select excerpt length for left welcome page', 'medplus-pro'),
		'id' => 'welcomepagelength',
		'std' => '50',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('manage read more button text for welcome page', 'medplus-pro'),
		'id' => 'welcomepagereadmore',
		'std' => 'Read More &raquo;',
		'type' => 'text');
	
	$options[] = array(	
		'desc'	=> __('Second Services box for frontpage section first','medplus-pro'),
		'id' 	=> 'box1',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for first box.', 'medplus-pro'),
		'id' => 'boximg1',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Second Services box for frontpage section first','medplus-pro'),
		'id' 	=> 'box2',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for second box.', 'medplus-pro'),
		'id' => 'boximg2',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Third Services box for frontpage section first','medplus-pro'),
		'id' 	=> 'box3',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for third box.', 'medplus-pro'),
		'id' => 'boximg3',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');	
	
	$options[] = array(	
		'desc'	=> __('Third Services box for frontpage section first','medplus-pro'),
		'id' 	=> 'box4',
		'type'	=> 'select',
		'options' => $options_pages,
	);	
	
	$options[] = array(		
		'desc' => __('upload image for fourth box.', 'medplus-pro'),
		'id' => 'boximg4',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(		
		'desc' => __('Select excerpt length for right page boxes', 'medplus-pro'),
		'id' => 'pageboxeslength',
		'std' => '30',
		'type' => 'text');	
		
	$options[] = array(			
			'desc'	=> __('Check to hide page boxes section', 'business-growth'),
			'id'	=> 'hidepageboxessec',
			'type'	=> 'checkbox',
			'std'	=> '');		
	
	$options[] = array(
		'name' => __('Number of Sections', 'medplus-pro'),
		'desc' => __('Select number of sections', 'medplus-pro'),
		'id' => 'numsection',
		'type' => 'select',
		'std' => '10',
		'options' => array_combine(range(1,30), range(1,30)) );

	$numsecs = of_get_option( 'numsection', 10 );

	for( $n=1; $n<=$numsecs; $n++){
		$options[] = array(
			'desc' => __("<h3>Section ".$n."</h3>", 'medplus-pro'),
			'class' => 'toggle_title',
			'type' => 'info');	
	
		$options[] = array(
			'name' => __('Section Title', 'medplus-pro'),
			'id' => 'sectiontitle'.$n,
			'std' => ( ( isset($section_text[$n]['section_title']) ) ? $section_text[$n]['section_title'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section ID', 'medplus-pro'),
			'desc'	=> __('Enter your section ID here. SECTION ID MUST BE IN SMALL LETTERS ONLY AND DO NOT ADD SPACE OR SYMBOL.', 'medplus-pro'),
			'id' => 'menutitle'.$n,
			'std' => ( ( isset($section_text[$n]['menutitle']) ) ? $section_text[$n]['menutitle'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section Background Color', 'medplus-pro'),
			'desc' => __('Select background color for section', 'medplus-pro'),
			'id' => 'sectionbgcolor'.$n,
			'std' => ( ( isset($section_text[$n]['bgcolor']) ) ? $section_text[$n]['bgcolor'] : '' ),
			'type' => 'color');
			
		$options[] = array(
			'name' => __('Background Image', 'medplus-pro'),
			'id' => 'sectionbgimage'.$n,
			'class' => '',
			'std' => ( ( isset($section_text[$n]['bgimage']) ) ? $section_text[$n]['bgimage'] : '' ),
			'type' => 'upload');

		$options[] = array(
			'name' => __('Section CSS Class', 'medplus-pro'),
			'desc' => __('Set class for this section.', 'medplus-pro'),
			'id' => 'sectionclass'.$n,
			'std' => ( ( isset($section_text[$n]['class']) ) ? $section_text[$n]['class'] : '' ),
			'type' => 'text');
			
		$options[] = array(
			'name'	=> __('Hide Section', 'medplus-pro'),
			'desc'	=> __('Check to hide this section', 'medplus-pro'),
			'id'	=> 'hidesec'.$n,
			'type'	=> 'checkbox',
			'std'	=> '');

		$options[] = array(
			'name' => __('Section Content', 'medplus-pro'),
			'id' => 'sectioncontent'.$n,
			'std' => ( ( isset($section_text[$n]['content']) ) ? $section_text[$n]['content'] : '' ),
			'type' => 'editor');
	}


	//SLIDER SETTINGS
	$options[] = array(
		'name' => __('Homepage Slider', 'medplus-pro'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Inner Page Banner', 'medplus-pro'),
		'desc' => __('Upload inner page banner for site', 'medplus-pro'),
		'id' => 'innerpagebanner',
		'class' => '',
		'std'	=> get_template_directory_uri()."/images/default-banner.jpg",
		'type' => 'upload');
		
		
	$options[] = array(
		'name' => __('Custom Slider Shortcode Area For Home Page', 'medplus-pro'),
		'desc' => __('Enter here your slider shortcode without php tag', 'medplus-pro'),
		'id' => 'customslider',
		'std' => '',
		'type' => 'textarea');		
		
	$options[] = array(
		'name' => __('Slider Effects and Timing', 'medplus-pro'),
		'desc' => __('Select slider effect.','medplus-pro'),
		'id' => 'slideefect',
		'std' => 'random',
		'type' => 'select',
		'options' => array('random'=>'Random', 'fade'=>'Fade', 'fold'=>'Fold', 'sliceDown'=>'Slide Down', 'sliceDownLeft'=>'Slide Down Left', 'sliceUp'=>'Slice Up', 'sliceUpLeft'=>'Slice Up Left', 'sliceUpDown'=>'Slice Up Down', 'sliceUpDownLeft'=>'Slice Up Down Left', 'slideInRight'=>'SlideIn Right', 'slideInLeft'=>'SlideIn Left', 'boxRandom'=>'Box Random', 'boxRain'=>'Box Rain', 'boxRainReverse'=>'Box Rain Reverse', 'boxRainGrow'=>'Box Rain Grow', 'boxRainGrowReverse'=>'Box Rain Grow Reverse' ));
		
	$options[] = array(
		'desc' => __('Animation speed should be multiple of 100.', 'medplus-pro'),
		'id' => 'slideanim',
		'std' => 500,
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add slide pause time.', 'medplus-pro'),
		'id' => 'slidepause',
		'std' => 4000,
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slide Controllers', 'medplus-pro'),
		'desc' => __('Hide/Show Direction Naviagtion of slider.','medplus-pro'),
		'id' => 'slidenav',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Hide/Show pager of slider.','medplus-pro'),
		'id' => 'slidepage',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Pause Slide on Hover.','medplus-pro'),
		'id' => 'slidepausehover',
		'std' => 'false',
		'type' => 'select',
		'options' => array('true'=>'Yes', 'false'=>'No'));
		
	$options[] = array(
		'name' => __('Slider Image 1', 'medplus-pro'),
		'desc' => __('First Slide', 'medplus-pro'),
		'id' => 'slide1',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider1.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 1', 'medplus-pro'),
		'id' => 'slidetitle1',
		'std' => '<strong>Medplus Theme is Perfect for your</strong><span>Medical and Health Related site!</span>',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'medplus-pro'),
		'id' => 'slidedesc1',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'medplus-pro'),
		'id' => 'slidebutton1',
		'std' => '',
		'type' => 'text');	

	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'medplus-pro'),
		'id' => 'slideurl1',
		'std' => '',
		'type' => 'text');		
		
	
	$options[] = array(
		'name' => __('Slider Image 2', 'medplus-pro'),
		'desc' => __('Second Slide', 'medplus-pro'),
		'class' => '',
		'id' => 'slide2',
		'std' => get_template_directory_uri()."/images/slides/slider2.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 2', 'medplus-pro'),
		'id' => 'slidetitle2',
		'std' => '<strong>Medplus Theme is Perfect for your</strong><span>Medical and Health Related site!</span>',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'medplus-pro'),
		'id' => 'slidedesc2',
		'std' => '',
		'type' => 'textarea');	
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'medplus-pro'),
		'id' => 'slidebutton2',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'medplus-pro'),
		'id' => 'slideurl2',
		'std' => '',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Slider Image 3', 'medplus-pro'),
		'desc' => __('Third Slide', 'medplus-pro'),
		'id' => 'slide3',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider3.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 3', 'medplus-pro'),
		'id' => 'slidetitle3',
		'std' => '<strong>Medplus Theme is Perfect for your</strong><span>Medical and Health Related site!</span>',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'medplus-pro'),
		'id' => 'slidedesc3',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'medplus-pro'),
		'id' => 'slidebutton3',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'medplus-pro'),
		'id' => 'slideurl3',
		'std' => '',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Slider Image 4', 'medplus-pro'),
		'desc' => __('Third Slide', 'medplus-pro'),
		'id' => 'slide4',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider4.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 4', 'medplus-pro'),
		'id' => 'slidetitle4',
		'std' => '<strong>Medplus Theme is Perfect for your</strong><span>Medical and Health Related site!</span>',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'medplus-pro'),
		'id' => 'slidedesc4',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'medplus-pro'),
		'id' => 'slidebutton4',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'medplus-pro'),
		'id' => 'slideurl4',
		'std' => '',
		'type' => 'text');				
	
	$options[] = array(
		'name' => __('Slider Image 5', 'medplus-pro'),
		'desc' => __('Fifth Slide', 'medplus-pro'),
		'id' => 'slide5',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 5', 'medplus-pro'),
		'id' => 'slidetitle5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'medplus-pro'),
		'id' => 'slidedesc5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'medplus-pro'),
		'id' => 'slidebutton5',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'medplus-pro'),
		'id' => 'slideurl5',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 6', 'medplus-pro'),
		'desc' => __('Sixth Slide', 'medplus-pro'),
		'id' => 'slide6',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 6', 'medplus-pro'),
		'id' => 'slidetitle6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'medplus-pro'),
		'id' => 'slidedesc6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'medplus-pro'),
		'id' => 'slidebutton6',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'medplus-pro'),
		'id' => 'slideurl6',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 7', 'medplus-pro'),
		'desc' => __('Seventh Slide', 'medplus-pro'),
		'id' => 'slide7',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 7', 'medplus-pro'),
		'id' => 'slidetitle7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'medplus-pro'),
		'id' => 'slidedesc7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'medplus-pro'),
		'id' => 'slidebutton7',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'medplus-pro'),
		'id' => 'slideurl7',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 8', 'medplus-pro'),
		'desc' => __('Eighth Slide', 'medplus-pro'),
		'id' => 'slide8',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 8', 'medplus-pro'),
		'id' => 'slidetitle8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'medplus-pro'),
		'id' => 'slidedesc8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'medplus-pro'),
		'id' => 'slidebutton8',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'medplus-pro'),
		'id' => 'slideurl8',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 9', 'medplus-pro'),
		'desc' => __('Ninth Slide', 'medplus-pro'),
		'id' => 'slide9',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 9', 'medplus-pro'),
		'id' => 'slidetitle9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'medplus-pro'),
		'id' => 'slidedesc9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'medplus-pro'),
		'id' => 'slidebutton9',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'medplus-pro'),
		'id' => 'slideurl9',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 10', 'medplus-pro'),
		'desc' => __('Tenth Slide', 'medplus-pro'),
		'id' => 'slide10',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 10', 'medplus-pro'),
		'id' => 'slidetitle10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'medplus-pro'),
		'id' => 'slidedesc10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'medplus-pro'),
		'id' => 'slidebutton10',
		'std' => '',
		'type' => 'text');			
	
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'medplus-pro'),
		'id' => 'slideurl10',
		'std' => '',
		'type' => 'text');
	

	//Footer SETTINGS
	$options[] = array(
		'name' => __('Footer', 'medplus-pro'),
		'type' => 'heading');
				
	$options[] = array(
		'name' => __('Footer About Us', 'medplus-pro'),
		'desc' => __('abput us text title for footer', 'medplus-pro'),
		'id' => 'abouttitle',
		'std' => 'About Us',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('About Us Description', 'medplus-pro'),
		'desc' => __('abput us text description for footer', 'medplus-pro'),
		'id' => 'aboutusdescription',
		'std' => '<p>Donec ut ex ac nulla pellentesque mollis in a enim Suspendisse suscipit velit id ultricies auctor. Duis turpis arcu, aliquet sed sollicitudin seduisque velit nibh.</br > </br >Donec ut ex ac nulla sapien mauris, vitae sodales tellus suspendisse suscipit velit id ultricies auctor.</p>',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Footer Menu Title', 'medplus-pro'),
		'desc' => __('footer menu title.', 'medplus-pro'),
		'id' => 'footermenutitle',
		'std' => 'Footer Menu',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Latest Posts Title', 'medplus-pro'),
		'desc' => __('Footer latest posts title.', 'medplus-pro'),
		'id' => 'letestpoststitle',
		'std' => 'Latest Posts',
		'type' => 'text');	
		
		
	$options[] = array(
		'name' => __('Footer Get in Touch', 'medplus-pro'),
		'desc' => __('Add footer get in touch title here', 'medplus-pro'),
		'id' => 'contacttitle',
		'std' => 'Get in touch',
		'type' => 'text');	
		
	$options[] = array(	
		'desc' => __('Add company address1 here.', 'medplus-pro'),
		'id' => 'address',
		'std' => '1600 Amphitheatre Parkway Mountain View, CA 94043',
		'type' => 'textarea');
		
	$options[] = array(		
		'desc' => __('Add phone number here.', 'medplus-pro'),
		'id' => 'phone',
		'std' => '+91 923456789',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Add fax number here.', 'medplus-pro'),
		'id' => 'fax',
		'std' => '+91 9876543210',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Add email address here.', 'medplus-pro'),
		'id' => 'email',
		'std' => 'info@buildpress.com',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Footer Social Icons', 'medplus-pro'),
		'desc' => __('social icons for footer', 'medplus-pro'),
		'id' => 'footersocialicon',
		'std' => '[social_area]
			[social icon="facebook" link="#"]
			[social icon="twitter" link="#"]
			[social icon="linkedin" link="#"]
			[social icon="google-plus" link="#"]
		[/social_area]
		',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Footer Copyright', 'medplus-pro'),
		'desc' => __('Copyright Text for your site.', 'medplus-pro'),
		'id' => 'copytext',
		'std' => '&copy; 2015 <a href="#">Medplus </a>. All Rights Reserved',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Footer Text Link', 'medplus-pro'),
		'id' => 'ftlink',
		'std' => 'Design by <a href="'.esc_url('http://www.gracethemes.com/').'" target="_blank">Grace Themes</a>',
		'type' => 'textarea',);
		
	$options[] = array(
		'desc' => __('Footer Back to Top Button', 'medplus-pro'),
		'id' => 'backtotop',
		'std' => '[back-to-top]',
		'type' => 'textarea',);

	//Short codes
	$options[] = array(
		'name' => __('Short Codes', 'medplus-pro'),
		'type' => 'heading');	
		
	
	$options[] = array(
		'name' => __('Photo Gallery', 'medplus-pro'),
		'desc' => __('[photogallery filter="false"]', 'medplus-pro'),
		'type' => 'info');			
			
		
	$options[] = array(
		'name' => __('Testimonials', 'medplus-pro'),
		'desc' => __('[testimonials]', 'medplus-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Contact Form', 'medplus-pro'),
		'desc' => __('[contactform to_email="test@example.com" title="Contact Form"] 
', 'medplus-pro'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Team Member', 'medplus-pro'),
		'desc' => __('[our-doctor show="4"] and all [our-doctor]', 'medplus-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Latest News', 'medplus-pro'),
		'desc' => __('[latest-news showposts="4" comment="show" date="show" author="hide"] and all [latest-news]', 'medplus-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Custom Button', 'medplus-pro'),
		'desc' => __('[button align="center" name="View Gallery" link="#" target=""]', 'medplus-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Our Skills', 'medplus-pro'),
		'desc' => __('[counter iconname="fa-user-md" value="35" title="Our Staff"][counter iconname="fa-wheelchair" value="15" title="Our Department"][counter iconname="fa-list" value="2560" title="Our Patient List"] [counter iconname="fa-graduation-cap" value="560" title="Our Awards"]', 'medplus-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Our Departments', 'medplus-pro'),
		'desc' => __('[departments_lists]<br />
		   [department image="enter here image path with http:" title="Enter here your title" link="#"]<br />
		   [department image="enter here image path with http:" title="Enter here your title" link="#"]<br />
		   [department image="enter here image path with http:" title="Enter here your title" link="#"]<br />
		  [/departments_lists]', 'medplus-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Our Partners', 'medplus-pro'),
		'desc' => __('[client_lists]<br />
		[client image="Enter here client image logo url with https:" link="#"]<br />
		[client image="Enter here client image logo url with https:" link="#"]<br />
		[client image="Enter here client image logo url with https:" link="#"]<br />
		[client image="Enter here client image logo url with https:" link="#"]<br />
		[client image="Enter here client image logo url with https:" link="#"]<br />
		[/client_lists]', 'medplus-pro'),
		'type' => 'info');							
			
		
	$options[] = array(
		'name' => __('Search Form', 'medplus-pro'),
		'desc' => __('[searchform]', 'medplus-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Social Icons ( Note: More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/)', 'medplus-pro'),
		'desc' => __('[social_area]<br />
			[social icon="facebook" link="#"]<br />
			[social icon="twitter" link="#"]<br />
			[social icon="linkedin" link="#"]<br />
			[social icon="google-plus" link="#"]<br />
		[/social_area]', 'medplus-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('2 Column Content', 'medplus-pro'),
		'desc' => __('<pre>
[column_content type="one_half"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_half_last"]
	Column 2 Content goes here...
[/column_content]
</pre>', 'medplus-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('3 Column Content', 'medplus-pro'),
		'desc' => __('<pre>
[column_content type="one_third"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_third"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_third_last"]
	Column 3 Content goes here...
[/column_content]
</pre>', 'medplus-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('4 Column Content', 'medplus-pro'),
		'desc' => __('<pre>
[column_content type="one_fourth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fourth_last"]
	Column 4 Content goes here...
[/column_content]
</pre>', 'medplus-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('5 Column Content', 'medplus-pro'),
		'desc' => __('<pre>
[column_content type="one_fifth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 4 Content goes here...
[/column_content]

[column_content type="one_fifth_last"]
	Column 5 Content goes here...
[/column_content]
</pre>', 'medplus-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('Tabs', 'medplus-pro'),
		'desc' => __('<pre>
[tabs]
	[tab title="TAB TITLE 1"]
		TAB CONTENT 1
	[/tab]
	[tab title="TAB TITLE 2"]
		TAB CONTENT 2
	[/tab]
	[tab title="TAB TITLE 3"]
		TAB CONTENT 3
	[/tab]
[/tabs]
</pre>', 'medplus-pro'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Toggle Content', 'medplus-pro'),
		'desc' => __('<pre>
[toggle_content title="Toggle Title 1"]
	Toggle content 1...
[/toggle_content]
[toggle_content title="Toggle Title 2"]
	Toggle content 2...
[/toggle_content]
[toggle_content title="Toggle Title 3"]
	Toggle content 3...
[/toggle_content]
</pre>', 'medplus-pro'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Accordion Content', 'medplus-pro'),
		'desc' => __('<pre>
[accordion]
	[accordion_content title="ACCORDION TITLE 1"]
		ACCORDION CONTENT 1
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 2"]
		ACCORDION CONTENT 2
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 3"]
		ACCORDION CONTENT 3
	[/accordion_content]
[/accordion]
</pre>', 'medplus-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Clear', 'medplus-pro'),
		'desc' => __('<pre>
[clear]
</pre>', 'medplus-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('HR / Horizontal separation line', 'medplus-pro'),
		'desc' => __('<pre>
[hr] or &lt;hr&gt;
</pre>', 'medplus-pro'),
		'type' => 'info');
	
	$options[] = array(
		'name' => __('Scroll to Top', 'medplus-pro'),
		'desc' => __('[back-to-top] 
', 'medplus-pro'),
		'type' => 'info');

	// Support					
	$options[] = array(
		'name' => __('Our Themes', 'medplus-pro'),
		'type' => 'heading');

	$options[] = array(
		'desc' => __('Medplus Pro WordPress theme has been Designed and Created by <a href="'.esc_url('http://gracethemes.com/').'" target="_blank">Grace Themes</a>', 'medplus-pro'),
		'type' => 'info');	

	 $options[] = array(
		'desc' => __('<a href="'.esc_url('http://gracethemes.com/').'" target="_blank"><img src="'.get_template_directory_uri().'/images/themesbunch.jpg"></a>', 'medplus-pro'),
		'type' => 'info');	

	return $options;
}